@@ -1,6 +1,5 @@
-import warnings
-
 from rubicon_ml.client import Base, TagMixin
+from rubicon_ml.client.utils.exception_handling import failsafe
 from rubicon_ml.exceptions import RubiconException
 
 
@@ -31,6 +30,7 @@ class Dataframe(Base, TagMixin):
         self._data = None
         self._parent = parent
 
+    @failsafe
     def get_data(self, df_type="pandas"):
         """Loads the data associated with this Dataframe
         into a `pandas` or `dask` dataframe.
@@ -38,8 +38,8 @@ class Dataframe(Base, TagMixin):
         Parameters
         ----------
         df_type : str, optional
-            The type of dataframe. Can be either `pandas` or `dask`.
-            Defaults to 'pandas'.
+            The type of dataframe to return. Valid options include
+            ["dask", "pandas"]. Defaults to "pandas".
         """
         project_name, experiment_id = self.parent._get_identifiers()
 
@@ -52,6 +52,7 @@ class Dataframe(Base, TagMixin):
 
         return self._data
 
+    @failsafe
     def plot(self, df_type="pandas", plotting_func=None, **kwargs):
         """Render the dataframe using `plotly.express`.
 
@@ -111,18 +112,6 @@ class Dataframe(Base, TagMixin):
         """Get the time this dataframe was created."""
         return self._domain.created_at
 
-    @property
-    def data(self):
-        """Get the dataframe's data as it was logged."""
-        warnings.warn(
-            "`data` is deprecated, use `get_data()` instead",
-            DeprecationWarning,
-        )
-        if self._data is None:
-            self.get_data()
-
-        return self._data
-
     @property
     def parent(self):
         """Get the dataframe's parent client object."""
